@@ -1603,6 +1603,94 @@ def test_custom_transformer():
     assert_result(result, expected_result_nodes)
 
 
+def test_blog_example():
+    wipe_all_neo4j_data(DRIVER)
+    from dict2graph import Node, AnyLabel
+    from dict2graph.transformers._base import _NodeTransformerBase
+
+    data = {
+        "shop": {
+            "name": "Helga`s Toolshop",
+            "inventory": [
+                {"hammer": {"price": 12.4, "brand": "DullHammers"}},
+                {"screwdriver": {"price": 9.99, "brand": "SharpDrivers"}},
+            ],
+        }
+    }
+    d2g = Dict2graph()
+    d2g.add_transformation(
+        Transformer.match_nodes("ListItem").do(
+            [
+                NodeTrans.ConvertLabelToProp(
+                    prop_key="name", target_labels=AnyLabel, omit_move_labels="ListItem"
+                ),
+                NodeTrans.AddLabel("Tool"),
+                NodeTrans.RemoveListItemLabels(),
+            ]
+        )
+    )
+    d2g.parse(data).create(DRIVER)
+    result = get_all_neo4j_nodes_with_rels(DRIVER)
+
+    expected_result_nodes: dict = [
+        {
+            "labels": ["inventory", "ListHub"],
+            "props": {"id": "32efdb27ef282ff16cddea6d7a64941d"},
+            "outgoing_rels": [
+                {
+                    "rel_props": {"_list_item_index": 1},
+                    "rel_type": "inventory_LIST_HAS_Tool",
+                    "rel_target_node": {
+                        "labels": ["Tool"],
+                        "props": {
+                            "price": 9.99,
+                            "name": "screwdriver",
+                            "brand": "SharpDrivers",
+                        },
+                    },
+                },
+                {
+                    "rel_props": {"_list_item_index": 0},
+                    "rel_type": "inventory_LIST_HAS_Tool",
+                    "rel_target_node": {
+                        "labels": ["Tool"],
+                        "props": {
+                            "price": 12.4,
+                            "name": "hammer",
+                            "brand": "DullHammers",
+                        },
+                    },
+                },
+            ],
+        },
+        {
+            "labels": ["Tool"],
+            "props": {"price": 12.4, "name": "hammer", "brand": "DullHammers"},
+            "outgoing_rels": [],
+        },
+        {
+            "labels": ["Tool"],
+            "props": {"price": 9.99, "name": "screwdriver", "brand": "SharpDrivers"},
+            "outgoing_rels": [],
+        },
+        {
+            "labels": ["shop"],
+            "props": {"name": "Helga`s Toolshop"},
+            "outgoing_rels": [
+                {
+                    "rel_props": {},
+                    "rel_type": "shop_HAS_inventory",
+                    "rel_target_node": {
+                        "labels": ["inventory", "ListHub"],
+                        "props": {"id": "32efdb27ef282ff16cddea6d7a64941d"},
+                    },
+                }
+            ],
+        },
+    ]
+    assert_result(result, expected_result_nodes)
+
+
 if __name__ == "__main__" or os.getenv("DICT2GRAPH_RUN_ALL_TESTS", False) == "true":
     test_readme_tiny_example()
     test_readme_start_example()
@@ -1627,3 +1715,4 @@ if __name__ == "__main__" or os.getenv("DICT2GRAPH_RUN_ALL_TESTS", False) == "tr
     test_hubbing_tut_ets_code_hub_01()
     test_hubbing_tut_ets_code_hub_02()
     test_custom_transformer()
+    test_blog_example()
